From 7990f8881b085279269d35cf9dd2787b88ae1c08 Mon Sep 17 00:00:00 2001
From: mcramer <m.cramer@pixcept.de>
Date: Tue, 27 Nov 2012 14:47:43 -0500
Subject: [PATCH] Bugfix: _ispconfig_pw_crypted was ignored (stripped off in encoding method)

---
 interface/lib/classes/tpl_ini.inc.php |   22 ++++++++++++----------
 1 files changed, 12 insertions(+), 10 deletions(-)

diff --git a/interface/lib/classes/tpl_ini.inc.php b/interface/lib/classes/tpl_ini.inc.php
index 48e0044..8388148 100644
--- a/interface/lib/classes/tpl_ini.inc.php
+++ b/interface/lib/classes/tpl_ini.inc.php
@@ -45,16 +45,17 @@
 
     class vlibIni{
 
-        /** config vars for vlibTemplate */
-        public static function vlibTemplate () {
-        	
-        	global $conf;
+        /** Returns $array of config vars for vlibTemplate */
+        public static function vlibTemplate()
+        {
 
-			$tpl_dir = $conf['rootpath'].'/web/themes/'.$_SESSION['s']['theme'].'/templates';
-			
+			$tpl_dir = ISPC_THEMES_PATH.'/'.$_SESSION['s']['theme'].'/templates';
+			$def_tpl_dir = ISPC_THEMES_PATH.'/default/templates';
             return array(
 
-                        'TEMPLATE_DIR' => $tpl_dir,   // Default directory for your template files (full path)
+                        'INCLUDE_PATHS' => array($tpl_dir),   // The path, searched BEVORE the template_dir is searched for the template-file
+
+                        'TEMPLATE_DIR' => $def_tpl_dir,			   // Default directory for your template files (full path)
                                                                    // leave the '/' or '\' off the end of the directory.
 
                         'MAX_INCLUDES' => 10,                      // Drill depth for tmpl_include's
@@ -88,8 +89,8 @@
 
 
                         /* the following are only used by the vlibTemplateCache class. */
-                        // TODO: triggers a notice as its not set
-                        'CACHE_DIRECTORY' => $conf['template']['cache_dir'],
+                        // pedro notes:: triggers a notice as its not set - was $conf['template']['cache_dir'],
+                        'CACHE_DIRECTORY' => ISPC_CACHE_PATH,
                                                                    // Directory where the cached filesystem
                                                                    // will be set up (full path, and must be writable)
                                                                    // '/' or '\' off the end of the directory.
@@ -104,7 +105,7 @@
 
 
 
         /** config vars for vlibDate */
         public function vlibDate()
         {
             return array( 'DEFAULT_LANG' => 'de' ); //* default language for the date displays
@@ -112,5 +113,6 @@
 
 
     }// << end class vlibIni
+
 } // << if Defined
 ?>
\ No newline at end of file
@@ -104,7 +105,7 @@
 
 
-        /** config vars for vlibDate */
+        /** Returns $array of config vars for vlibDate */
         public function vlibDate()
         {

--
Gitblit v1.9.1